@@ -1,3 +1,4 @@
+import time
 import requests
 
 
@@ -25,6 +26,7 @@ def request_handler(url, method, data=None, json=None, params=None, count=0,retr
     except Exception as error:
         if count > retry:
             return None
+        time.sleep(2)
         return request_handler(url, method, data=data, json=json, params=params, count=count + 1, **kwargs)
 
 
